@@ -33,7 +33,7 @@ function getCsrfToken(){
     if (call.stack.length) {
       let s = call.stack;
       call.stack = [];
-      headers = {
+      var headers = {
         "Content-Type": "application/json;charset=UTF-8",
         "X-CSRFToken": getCsrfToken()
       }
